@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="es">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
 <context>
     <name>MainWindow</name>
     <message>
@@ -150,7 +148,6 @@
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="180"/>
-        <location filename="../mainwindow.cpp" line="308"/>
         <source>Failure</source>
         <translation>Falla</translation>
     </message>
@@ -213,11 +210,6 @@
         <source>%1 Help</source>
         <translation>%1 Ayuda</translation>
     </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="308"/>
-        <source>Invalid Name</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -243,4 +235,4 @@
         <translation>&amp;Cerrar</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
